@@ -4,7 +4,7 @@ RSpec.describe Guard::Nanoc do
   around do |example|
     Dir.mktmpdir('nanoc-test') do |dir|
       __nanoc_core_chdir(dir) do
-        ::Nanoc::CLI.run(%w[create-site foo])
+        Nanoc::CLI.run(%w[create-site foo])
         __nanoc_core_chdir('foo') do
           example.run
         end
@@ -13,6 +13,6 @@ RSpec.describe Guard::Nanoc do
   end
 
   it 'loads the command properly' do
-    expect { ::Nanoc::CLI.run(%w[live]) }.to raise_error(/No Guardfile found, please create one/)
+    expect { Nanoc::CLI.run(%w[live]) }.to raise_error(/No Guardfile found, please create one/)
   end
 end
