@@ -105,25 +105,26 @@ module Nanoc::CLI::Commands
               raise Nanoc::Core::Errors::InternalInconsistency, "unexpected pred type #{pred.inspect}"
             end
 
-          pred_identifier =
+          details =
             case pred
             when Nanoc::Core::Document
-              pred.identifier.to_s
+              [pred.identifier.to_s]
             when Nanoc::Core::Configuration, nil
-              nil
+              []
             when Nanoc::Core::IdentifiableCollection
-              case dep.props.raw_content
-              when true
-                'matching any'
-              else
-                "matching any of #{dep.props.raw_content.sort.join(', ')}"
-              end
+              describe_identifiable_collection_dependency(dep)
             else
               raise Nanoc::Core::Errors::InternalInconsistency, "unexpected pred type #{pred.inspect}"
             end
 
           if pred
-            puts "  [ #{format '%6s', type} ] (#{dep.props}) #{pred_identifier}"
+            print "  [ #{format '%7s', type} ] (#{dep.props})"
+
+            if details.any?
+              print ' '
+            end
+
+            puts details.join("\n                     ")
           else
             puts '  ( removed )'
           end
@@ -132,6 +133,47 @@ module Nanoc::CLI::Commands
       end
     end
 
+    def describe_identifiable_collection_dependency(dep)
+      outcome = []
+
+      case dep.props.raw_content
+      when true
+        outcome << 'matching any identifier'
+      when Set
+        dep.props.raw_content.sort.each do |x|
+          outcome << "matching identifier #{x}"
+        end
+      end
+
+      if dep.props.attributes
+        case dep.props.attributes
+        when true
+          outcome << 'matching any attribute'
+        when Set
+          dep.props.attributes.each do |elem|
+            case elem
+            when Symbol
+              outcome << "matching attribute #{elem.inspect} (any value)"
+            when Array
+              outcome << "matching attribute pair #{elem[0].inspect} => #{elem[1].inspect}"
+            else
+              raise(
+                Nanoc::Core::Errors::InternalInconsistency,
+                "unexpected prop attribute element #{elem.inspect}",
+              )
+            end
+          end
+        else
+          raise(
+            Nanoc::Core::Errors::InternalInconsistency,
+            "unexpected prop attribute #{dep.props.attributes.inspect}",
+          )
+        end
+      end
+
+      outcome
+    end
+
     def print_item_rep_paths(items, reps)
       print_header('Item representation paths')
 
