@@ -7,11 +7,9 @@ module Nanoc
       include Enumerable
       prepend MemoWise
 
-      attr_reader :item_rep
       attr_reader :actions
 
-      def initialize(item_rep, actions: [])
-        @item_rep = item_rep
+      def initialize(actions: [])
         @actions = actions
       end
 
@@ -46,16 +44,15 @@ module Nanoc
       end
 
       # contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
-      def each
-        @actions.each { |a| yield(a) }
+      def each(&block)
+        @actions.each(&block)
         self
       end
 
       # contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
-      def map
+      def map(&block)
         self.class.new(
-          @item_rep,
-          actions: @actions.map { |a| yield(a) },
+          actions: @actions.map(&block),
         )
       end
     end
