@@ -16,11 +16,13 @@ module Nanoc
 
       contract C::KeywordArgs[config: Nanoc::Core::Configuration, objects: C::IterOf[c_obj]] => C::Any
       def initialize(config:, objects:)
-        super(Nanoc::Core::Store.tmp_path_for(config: config, store_name: 'checksums'), 2)
+        super(Nanoc::Core::Store.tmp_path_for(config: config, store_name: 'checksums'), 3)
 
         @objects = objects
 
         @checksums = {}
+
+        invalidate_memoization
       end
 
       contract c_obj => C::Maybe[String]
@@ -50,7 +52,7 @@ module Nanoc
 
       contract c_obj => C::Maybe[C::HashOf[Symbol, String]]
       def attributes_checksum_for(obj)
-        @checksums[[obj.reference, :each_attribute]]
+        @_attribute_checksums[obj] ||= @checksums[[obj.reference, :each_attribute]]
       end
 
       protected
@@ -60,6 +62,8 @@ module Nanoc
       end
 
       def data=(new_data)
+        invalidate_memoization
+
         references = Set.new(@objects.map(&:reference))
 
         @checksums = {}
@@ -69,6 +73,12 @@ module Nanoc
           end
         end
       end
+
+      private
+
+      def invalidate_memoization
+        @_attribute_checksums = {}
+      end
     end
   end
 end
