@@ -5,7 +5,7 @@ describe Nanoc::Core::CompilationStages::CompileReps do
     identifier :simple_erb_vcn3np2ayqmv6ayqp8su2crbusonmgwh
 
     def run(content, _params = {})
-      context = ::Nanoc::Core::Context.new(assigns)
+      context = Nanoc::Core::Context.new(assigns)
       ERB.new(content).result(context.get_binding)
     end
   end
@@ -124,9 +124,9 @@ describe Nanoc::Core::CompilationStages::CompileReps do
     end
 
     context 'rep in outdatedness store' do
-      before { outdatedness_store.add(rep) }
-
       before do
+        outdatedness_store.add(rep)
+
         # Needed for consistency
         compiled_content_cache[other_rep] = { last: Nanoc::Core::TextualContent.new('asdf') }
       end
