@@ -174,7 +174,7 @@ shared_examples 'an item rep view' do
     let(:item) { Nanoc::Core::Item.new('asdf', {}, '/foo') }
     let(:view) { described_class.new(item_rep, view_context) }
 
-    it { is_expected.to eq described_class.hash ^ Nanoc::Core::Identifier.new('/foo').hash ^ :jacques.hash }
+    it { is_expected.to eq([described_class, Nanoc::Core::Identifier.new('/foo'), :jacques].hash) }
   end
 
   describe '#snapshot?' do
@@ -212,11 +212,11 @@ shared_examples 'an item rep view' do
         subject
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-        expect(dep.props.compiled_content?).to eq(true)
+        expect(dep.props.compiled_content?).to be(true)
 
-        expect(dep.props.raw_content?).to eq(false)
-        expect(dep.props.attributes?).to eq(false)
-        expect(dep.props.path?).to eq(false)
+        expect(dep.props.raw_content?).to be(false)
+        expect(dep.props.attributes?).to be(false)
+        expect(dep.props.path?).to be(false)
       end
 
       it { is_expected.not_to be(false) }
@@ -233,11 +233,11 @@ shared_examples 'an item rep view' do
         subject
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-        expect(dep.props.compiled_content?).to eq(true)
+        expect(dep.props.compiled_content?).to be(true)
 
-        expect(dep.props.raw_content?).to eq(false)
-        expect(dep.props.attributes?).to eq(false)
-        expect(dep.props.path?).to eq(false)
+        expect(dep.props.raw_content?).to be(false)
+        expect(dep.props.attributes?).to be(false)
+        expect(dep.props.path?).to be(false)
       end
 
       it { is_expected.to be(false) }
@@ -269,11 +269,11 @@ shared_examples 'an item rep view' do
       subject
       dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
-      expect(dep.props.path?).to eq(true)
+      expect(dep.props.path?).to be(true)
 
-      expect(dep.props.raw_content?).to eq(false)
-      expect(dep.props.attributes?).to eq(false)
-      expect(dep.props.compiled_content?).to eq(false)
+      expect(dep.props.raw_content?).to be(false)
+      expect(dep.props.attributes?).to be(false)
+      expect(dep.props.compiled_content?).to be(false)
     end
 
     it { is_expected.to eq('/about/') }
