@@ -151,7 +151,7 @@ module Nanoc::DataSources
     end
 
     def read_proto_document(content_filename, meta_filename, klass)
-      is_binary = content_filename && !@site_config[:text_extensions].include?(File.extname(content_filename)[1..-1])
+      is_binary = content_filename && !@site_config[:text_extensions].include?(File.extname(content_filename)[1..])
 
       if is_binary && klass == Nanoc::Core::Item
         meta = (meta_filename && YAML.safe_load_file(meta_filename, permitted_classes: PERMITTED_YAML_CLASSES)) || {}
@@ -252,7 +252,7 @@ module Nanoc::DataSources
         filename: content_filename,
         content_filename: content_filename,
         meta_filename: meta_filename,
-        extension: content_filename ? ext_of(content_filename)[1..-1] : nil,
+        extension: content_filename ? ext_of(content_filename)[1..] : nil,
         mtime: mtime_of(content_filename, meta_filename),
       }
     end
@@ -263,9 +263,9 @@ module Nanoc::DataSources
 
     def identifier_for(content_filename, meta_filename, dir_name)
       if content_filename
-        identifier_for_filename(content_filename[dir_name.length..-1])
+        identifier_for_filename(content_filename[dir_name.length..])
       elsif meta_filename
-        identifier_for_filename(meta_filename[dir_name.length..-1])
+        identifier_for_filename(meta_filename[dir_name.length..])
       else
         raise 'meta_filename and content_filename are both nil'
       end
@@ -284,15 +284,11 @@ module Nanoc::DataSources
     def mtime_of(content_filename, meta_filename)
       meta_mtime = meta_filename ? File.stat(meta_filename).mtime : nil
       content_mtime = content_filename ? File.stat(content_filename).mtime : nil
-      if meta_mtime && content_mtime
-        meta_mtime > content_mtime ? meta_mtime : content_mtime
-      elsif meta_mtime
-        meta_mtime
-      elsif content_mtime
-        content_mtime
-      else
-        raise 'meta_mtime and content_mtime are both nil'
-      end
+
+      mtime = [meta_mtime, content_mtime].compact.max
+      raise 'meta_mtime and content_mtime are both nil' unless mtime
+
+      mtime
     end
 
     # e.g.
@@ -330,7 +326,7 @@ module Nanoc::DataSources
         all[basename][0] =
           meta_filenames[0] ? 'yaml' : nil
         all[basename][1] =
-          content_filenames.any? ? content_filenames.map { |fn| ext_of(fn)[1..-1] || '' } : [nil]
+          content_filenames.any? ? content_filenames.map { |fn| ext_of(fn)[1..] || '' } : [nil]
       end
 
       all
