@@ -75,7 +75,7 @@ module Nanoc::Helpers
 
         compiled_content_store = @config._context.compiled_content_store
         content = compiled_content_store.get(rep, "__capture_#{@name}".to_sym)
-        content ? content.string : nil
+        content&.string
       end
     end
 
@@ -155,7 +155,7 @@ module Nanoc::Helpers
       yield
 
       # Get new piece of erbout
-      erbout_addition = erbout[erbout_length..-1]
+      erbout_addition = erbout[erbout_length..]
 
       # Remove addition
       erbout[erbout_length..-1] = +''
