@@ -8,8 +8,8 @@ module Nanoc::Helpers
     # @param [String] identifier
     # @param [Hash] other_assigns
     #
-    # @raise [Nanoc::Int::Errors::UnknownLayout]
-    # @raise [Nanoc::Int::Errors::CannotDetermineFilter]
+    # @raise [Nanoc::Core::Errors::UnknownLayout]
+    # @raise [Nanoc::Core::Errors::CannotDetermineFilter]
     # @raise [Nanoc::Filter::UnknownFilter]
     #
     # @return [String, nil]
@@ -17,7 +17,7 @@ module Nanoc::Helpers
       # Find layout
       layout_view = @layouts[identifier]
       layout_view ||= @layouts[identifier.__nanoc_cleaned_identifier]
-      raise Nanoc::Int::Errors::UnknownLayout.new(identifier) if layout_view.nil?
+      raise Nanoc::Core::Errors::UnknownLayout.new(identifier) if layout_view.nil?
 
       layout = layout_view._unwrap
 
@@ -33,6 +33,7 @@ module Nanoc::Helpers
         content: captured_content,
         item: @item,
         item_rep: @item_rep,
+        rep: @item_rep,
         items: @items,
         layout: layout_view,
         layouts: @layouts,
@@ -43,7 +44,7 @@ module Nanoc::Helpers
       filter_name_and_args = @config._context.compilation_context.filter_name_and_args_for_layout(layout)
       filter_name = filter_name_and_args.name
       filter_args = filter_name_and_args.args
-      raise Nanoc::Int::Errors::CannotDetermineFilter.new(layout.identifier) if filter_name.nil?
+      raise Nanoc::Core::Errors::CannotDetermineFilter.new(layout.identifier) if filter_name.nil?
 
       # Get filter class
       filter_class = Nanoc::Filter.named!(filter_name)
