@@ -2,6 +2,7 @@
 
 describe Nanoc::DataSources::Filesystem, site: true do
   let(:data_source) { described_class.new(site.config, nil, nil, params) }
+  let(:now) { Time.local(2008, 1, 2, 14, 5, 0) }
   let(:params) { {} }
   let(:site) { Nanoc::Core::SiteLoader.new.new_from_cwd }
 
@@ -9,8 +10,6 @@ describe Nanoc::DataSources::Filesystem, site: true do
 
   after { Timecop.return }
 
-  let(:now) { Time.local(2008, 1, 2, 14, 5, 0) }
-
   describe '#load_objects' do
     subject { data_source.send(:load_objects, dir_with_objects, klass) }
 
@@ -71,11 +70,11 @@ describe Nanoc::DataSources::Filesystem, site: true do
           end
 
           it 'has a different attributes checksum' do
-            expect(block).to change { data_source.send(:load_objects, 'foo', klass)[0].attributes_checksum_data }
+            expect(&block).to change { data_source.send(:load_objects, 'foo', klass)[0].attributes_checksum_data }
           end
 
           it 'has the same content checksum' do
-            expect(block).not_to change { data_source.send(:load_objects, 'foo', klass)[0].content_checksum_data }
+            expect(&block).not_to change { data_source.send(:load_objects, 'foo', klass)[0].content_checksum_data }
           end
         end
       end
@@ -279,40 +278,71 @@ describe Nanoc::DataSources::Filesystem, site: true do
       if Nanoc::Core.on_windows?
         skip 'nanoc-live is not currently supported on Windows'
       end
-
-      FileUtils.mkdir_p(temp_dir_base_expanded)
     end
 
-    after do
-      FileUtils.rm_rf(temp_dir_base_expanded)
-    end
-
-    it 'returns a stream' do
-      expect(subject).to be_a(Nanoc::Core::ChangesStream)
-    end
-
-    it 'contains one element after changing' do
-      FileUtils.mkdir_p(File.join(temp_dir, 'content'))
-
-      enum = SlowEnumeratorTools.buffer(subject.to_enum, 1)
-      q = SizedQueue.new(1)
-      Thread.new { q << enum.take(1).first }
-
-      # Try until we find a change
-      ok = false
-      20.times do |i|
-        File.write(File.join(temp_dir, 'content/wat.md'), "stuff #{i}")
-        begin
-          expect(q.pop(true)).to eq(:unknown)
-          ok = true
-          break
-        rescue ThreadError
-          sleep 0.1
-        end
+    context 'when directory exists' do
+      before do
+        FileUtils.mkdir_p(temp_dir_base_expanded)
       end
-      expect(ok).to be(true)
 
-      subject.stop
+      after do
+        FileUtils.rm_rf(temp_dir_base_expanded)
+      end
+
+      it 'returns a stream' do
+        expect(subject).to be_a(Nanoc::Core::ChangesStream)
+      end
+
+      it 'contains one element after changing' do
+        FileUtils.mkdir_p(File.join(temp_dir, 'content'))
+
+        enum = SlowEnumeratorTools.buffer(subject.to_enum, 1)
+        q = SizedQueue.new(1)
+        Thread.new { q << enum.take(1).first }
+
+        # Try until we find a change
+        ok = false
+        20.times do |i|
+          File.write(File.join(temp_dir, 'content/wat.md'), "stuff #{i}")
+          begin
+            expect(q.pop(true)).to eq(:unknown)
+            ok = true
+            break
+          rescue ThreadError
+            sleep 0.1
+          end
+        end
+        expect(ok).to be(true)
+
+        subject.stop
+      end
+    end
+
+    context 'when directory does not exist' do
+      it 'returns a stream' do
+        expect(subject).to be_a(Nanoc::Core::ChangesStream)
+      end
+
+      it 'does not raise' do
+        subject
+
+        t = Thread.new do
+          Thread.current.abort_on_exception = true
+          Thread.current.report_on_exception = false
+
+          begin
+            Timeout.timeout(0.1) { subject.to_enum.take(1).first }
+            Thread.current[:outcome] = :not_timed_out
+          rescue Timeout::Error
+            Thread.current[:outcome] = :timed_out
+          end
+        end
+
+        t.join
+        expect(t[:outcome]).to eq(:timed_out)
+
+        subject.stop
+      end
     end
   end
 end
