@@ -3,10 +3,10 @@
 describe Nanoc::Filters::SassCommon do
   context 'with item, items, config context' do
     subject(:sass_sourcemap) do
-      ::Nanoc::Filter.named(:sass_sourcemap).new(sass_sourcemap_params)
+      Nanoc::Filter.named(:sass_sourcemap).new(sass_sourcemap_params)
     end
 
-    let(:sass) { ::Nanoc::Filter.named(:sass).new(sass_params) }
+    let(:sass) { Nanoc::Filter.named(:sass).new(sass_params) }
 
     let(:sass_params) do
       {
@@ -266,7 +266,7 @@ describe Nanoc::Filters::SassCommon do
 
     it 'raises proper error on failure' do
       expect { sass.setup_and_run('$*#&!@($') }
-        .to raise_error(::Sass::SyntaxError, /Invalid variable/)
+        .to raise_error(Sass::SyntaxError, /Invalid variable/)
     end
 
     context 'importing a file for which an item exists' do
@@ -279,9 +279,9 @@ describe Nanoc::Filters::SassCommon do
 
       it 'cannot import by nested relative path' do
         expect { sass.setup_and_run('@import content/style/colors/blue') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
         expect { sass.setup_and_run('@import content/style/colors/red') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'can import by relative path with extension' do
@@ -293,9 +293,9 @@ describe Nanoc::Filters::SassCommon do
 
       it 'cannot import by nested relative path with extension' do
         expect { sass.setup_and_run('@import content/style/colors/blue.sass') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
         expect { sass.setup_and_run('@import content/style/colors/red.scss') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'can import SCSS partials by relative path' do
@@ -310,12 +310,12 @@ describe Nanoc::Filters::SassCommon do
 
       it 'cannot import anonymous SASS partials by relative path' do
         expect { sass.setup_and_run('@import anonymous-sass-partial') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'cannot import partials by nested relative path' do
         expect { sass.setup_and_run('@import content/style/_partial') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'can import partials by relative path with SCSS extension' do
@@ -330,22 +330,22 @@ describe Nanoc::Filters::SassCommon do
 
       it 'cannot import partials by relative path without extension' do
         expect { sass.setup_and_run('@import anonymous-sass-partial') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'cannot import partials by nested relative path with SCSS extension' do
         expect { sass.setup_and_run('@import content/style/partial.scss') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'cannot import partials by nested relative path with SASS extension' do
         expect { sass.setup_and_run('@import content/style/sass-partial.sass') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'cannot import partials by nested relative path without extension' do
         expect { sass.setup_and_run('@import content/style/anonymous-sass-partial') }
-          .to raise_error(::Sass::SyntaxError, /File to import not found/)
+          .to raise_error(Sass::SyntaxError, /File to import not found/)
       end
 
       it 'creates a dependency' do
@@ -372,7 +372,7 @@ describe Nanoc::Filters::SassCommon do
       context 'load_path not set' do
         it 'cannot import (using load paths) by relative path' do
           expect { sass.setup_and_run('@import external') }
-            .to raise_error(::Sass::SyntaxError, /File to import not found/)
+            .to raise_error(Sass::SyntaxError, /File to import not found/)
         end
 
         it 'can import (using importer) by relative path' do
