@@ -11,7 +11,7 @@ describe 'GH-1428', site: true, stdio: true do
     EOS
   end
 
-  example do
+  example do # rubocop:disable RSpec/NoExpectationExample
     Nanoc::CLI.run([])
     Nanoc::CLI.run(['show-data'])
   end
