@@ -191,16 +191,16 @@ describe(Nanoc::RuleDSL::ActionSequenceCalculator) do
     subject { action_sequence_calculator.compact_snapshots(action_sequence) }
 
     let(:action_sequence) do
-      Nanoc::Core::ActionSequenceBuilder.build(rep) do |b|
-        b.add_snapshot(:a1, nil)
-        b.add_snapshot(:a2, '/a2.md')
-        b.add_snapshot(:a3, nil)
+      Nanoc::Core::ActionSequenceBuilder.build do |b|
+        b.add_snapshot(:a1, nil, rep)
+        b.add_snapshot(:a2, '/a2.md', rep)
+        b.add_snapshot(:a3, nil, rep)
         b.add_filter(:erb, awesomeness: 'high')
-        b.add_snapshot(:b1, '/b1.md')
-        b.add_snapshot(:b2, nil)
-        b.add_snapshot(:b3, '/b3.md')
+        b.add_snapshot(:b1, '/b1.md', rep)
+        b.add_snapshot(:b2, nil, rep)
+        b.add_snapshot(:b3, '/b3.md', rep)
         b.add_filter(:erb, awesomeness: 'high')
-        b.add_snapshot(:c, nil)
+        b.add_snapshot(:c, nil, rep)
       end
     end
 
